@@ -8,7 +8,7 @@
  * 									*
  * 									*
  * Released under the GPLv3 only.					*
- * SPDX-License-Identifier: GPL-3.0					*
+ * SPDX-License-Identifier: GPL-3.0-only				*
  *									*
  ************************************************************************
  */
@@ -23,7 +23,7 @@
 /*
  * buffers and messages test program.
  */
-int main(int argc, char** argv)
+int main(void)
 {
 	struct mgebuffer buf = MGEBUFFER_INIT;
 	struct mgemessage msg = MGEMESSAGE_INIT(';', ',');
