@@ -1,14 +1,14 @@
 /* **********************************************************************
  *									*
  * Source: main.c							*
- * Author Copyright (C) 2017-2019  Mark Grant				*
+ * Author Copyright (C) 2017-2019, 2021  Mark Grant			*
  *									*
  * Purpose:								*
  *	Test program for error descriptions in libmgec shared library.	*
  * 									*
  * 									*
  * Released under the GPLv3 only.					*
- * SPDX-License-Identifier: GPL-3.0					*
+ * SPDX-License-Identifier: GPL-3.0-only				*
  *									*
  ************************************************************************
  */
@@ -27,7 +27,7 @@ extern const size_t errno_desc_size;	/* Need this for testing */
 /*
  * mge_errno test program.
  */
-int main(int argc, char** argv)
+int main(void)
 {
 	int i;
 
